@@ -38,7 +38,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.0.2"
+__version__ = "3.1.2"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_turtle.git"
 
 
@@ -46,21 +46,84 @@ class Color:
     """Standard colors"""
 
     WHITE = 0xFFFFFF
+    """0xFFFFFF
+
+    :meta hide-value:"""
+
     BLACK = 0x000000
+    """0x000000
+
+    :meta hide-value:"""
+
     RED = 0xFF0000
+    """0xFF0000
+
+    :meta hide-value:"""
+
     ORANGE = 0xFFA500
+    """0xFFA500
+
+    :meta hide-value:"""
+
     YELLOW = 0xFFEE00
+    """0xFFEE00
+
+    :meta hide-value:"""
+
     GREEN = 0x00C000
+    """0x00C000
+
+    :meta hide-value:"""
+
     BLUE = 0x0000FF
+    """0x0000FF
+
+    :meta hide-value:"""
+
     PURPLE = 0x8040C0
+    """0x8040C0
+
+    :meta hide-value:"""
+
     PINK = 0xFF40C0
+    """0xFF40C0
+
+    :meta hide-value:"""
+
     LIGHT_GRAY = 0xAAAAAA
+    """0xAAAAAA
+
+    :meta hide-value:"""
+
     GRAY = 0x444444
+    """0x444444
+
+    :meta hide-value:"""
+
     BROWN = 0xCA801D
+    """0xCA801D
+
+    :meta hide-value:"""
+
     DARK_GREEN = 0x008700
+    """0x008700
+
+    :meta hide-value:"""
+
     TURQUOISE = 0x00C0C0
+    """0x00C0C0
+
+    :meta hide-value:"""
+
     DARK_BLUE = 0x0000AA
+    """0x0000AA
+
+    :meta hide-value:"""
+
     DARK_RED = 0x800000
+    """0x800000
+
+    :meta hide-value:"""
 
     colors = (
         BLACK,
@@ -171,11 +234,11 @@ class turtle:
         self._y = self._h // (2 * scale)
         self._speed = 6
         self._heading: float = 0
-        self._logomode = True
         self._fullcircle = 360.0
         self._degreesPerAU = 1.0
-        self._angleOrient = 1
-        self._angleOffset: float = 0
+        self._logomode = False
+        self._angleOrient = -1
+        self._angleOffset: float = self._fullcircle / 4
         self._bg_color = 0
 
         self._splash: displayio.Group = displayio.Group()
@@ -248,6 +311,8 @@ class turtle:
         self._turtle_pic = None
         self._turtle_odb = None
         self._turtle_alt_sprite = None
+        self._turtle_x = self._x
+        self._turtle_y = self._y
         self._drawturtle()
         self._stamps = {}
         self._turtle_odb_use = 0
@@ -260,15 +325,23 @@ class turtle:
 
     def _drawturtle(self) -> None:
         if self._turtle_pic is None:
-            self._turtle_sprite.x = int(self._x - 4)
-            self._turtle_sprite.y = int(self._y - 4)
+            self._turtle_sprite.x = int(self._turtle_x - 4)
+            self._turtle_sprite.y = int(self._turtle_y - 4)
         else:
             if self._turtle_odb is not None:
-                self._turtle_alt_sprite.x = int(self._x - self._turtle_odb.width // 2)
-                self._turtle_alt_sprite.y = int(self._y - self._turtle_odb.height // 2)
+                self._turtle_alt_sprite.x = int(
+                    self._turtle_x - self._turtle_odb.width // 2
+                )
+                self._turtle_alt_sprite.y = int(
+                    self._turtle_y - self._turtle_odb.height // 2
+                )
             else:
-                self._turtle_alt_sprite.x = int(self._x - self._turtle_pic[0] // 2)
-                self._turtle_alt_sprite.y = int(self._y - self._turtle_pic[1] // 2)
+                self._turtle_alt_sprite.x = int(
+                    self._turtle_x - self._turtle_pic[0] // 2
+                )
+                self._turtle_alt_sprite.y = int(
+                    self._turtle_y - self._turtle_pic[1] // 2
+                )
 
     ###########################################################################
     # Move and draw
@@ -344,13 +417,17 @@ class turtle:
         xn: float = x1[0] if y1 is None else x1  # type: ignore
         xn += self._w // 2
         yn = self._h // 2 - yn
-        x0 = self._x
-        y0 = self._y
         if not self.isdown():
             self._x = xn  # woot, we just skip ahead
             self._y = yn
             self._drawturtle()
             return
+
+        self._do_draw_line(round(self._x), round(self._y), round(xn), round(yn))
+        self._x = xn
+        self._y = yn
+
+    def _do_draw_line(self, x0: int, y0: int, xn: int, yn: int):
         steep = abs(yn - y0) > abs(xn - x0)
         rev = False
         dx = xn - x0
@@ -381,15 +458,15 @@ class turtle:
                     self._plot(int(y0), int(x0), self._pencolor)
                 except IndexError:
                     pass
-                self._x = y0
-                self._y = x0
+                self._turtle_x = y0
+                self._turtle_y = x0
             else:
                 try:
                     self._plot(int(x0), int(y0), self._pencolor)
                 except IndexError:
                     pass
-                self._x = x0
-                self._y = y0
+                self._turtle_x = x0
+                self._turtle_y = y0
             if self._speed > 0:
                 if step >= self._speed:
                     # mark the step
